#!/bin/sh
set -e

CONFIG_FILE=/etc/cfs.conf

# source config file
test ! -r "$CONFIG_FILE" || . "$CONFIG_FILE"

test -n "$CRYPT_ROOT" || exit 0
test -n "$NULL_EXPORT" || exit 0

missing_export () {
    cat <<EOT >&2
failed.
When using cfs with the nfs-user-server package, add the following line
to /etc/exports and reload the nfs-user-server, then start cfsd again:

$NULL_EXPORT localhost(rw)

Not starting cfs.

EOT
}

if test -x /usr/sbin/exportfs; then
  # nfs-kernel-server
  exportfs -i -orw localhost:$NULL_EXPORT
  if ! grep '^/' /etc/exports >/dev/null; then
    # no exports, start temporary rcp.mountd
    rpc.mountd -F -P3048 -V2 2>/dev/null &
    MOUNTD=$!
    trap "kill -TERM $MOUNTD" EXIT
    echo -n 'mountd... '
  fi
else
  # nfs-user-server
  if ! grep "^$NULL_EXPORT[[:space:]]*localhost(rw" \
    /etc/exports >/dev/null; then
    missing_export
    exit 1
  fi
fi
umount $CRYPT_ROOT >/dev/null 2>&1 || :
rpcinfo -u 127.0.0.1 mountd 2 >/dev/null 2>&1 || sleep 1
rpcinfo -u 127.0.0.1 mountd 2 || exit 1
rc=0
mount -oport=3049,intr,nfsvers=2 \
  localhost:$NULL_EXPORT $CRYPT_ROOT || rc=1
test ! -x /usr/sbin/exportfs || exportfs -u localhost:$NULL_EXPORT

exit $rc
